<?php

// autoload_namespaces.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname($vendorDir);

return array(
    'Zend_' => array($vendorDir . '/shardj/zf1-future/library'),
    'Parsedown' => array($vendorDir . '/erusev/parsedown'),
    'Less' => array($vendorDir . '/wikimedia/less.php/lib'),
    'JShrink' => array($vendorDir . '/tedivm/jshrink/src'),
    'HTMLPurifier' => array($vendorDir . '/ezyang/htmlpurifier/library'),
    'Clue\\Redis\\Protocol' => array($vendorDir . '/clue/redis-protocol/src'),
    'AssetLoader' => array($baseDir . '/'),
);
